using Communication = Microsoft.Maui.ApplicationModel.Communication;


namespace Demo;

public partial class GsmPage : ContentPage
{
    public GsmPage()
    {
        InitializeComponent();
    }
    private async void OnSendSmsClicked(object sender, EventArgs e)
    {
        string phoneNumber = PhoneNumberEntry.Text;
        string message = MessageEditor.Text;

        if (string.IsNullOrEmpty(phoneNumber) || string.IsNullOrEmpty(message))
        {
            await DisplayAlert("Bd", "Prosz wypeni wszystkie pola.", "OK");
            return;
        }

        if (Sms.Default.IsComposeSupported)
        {
            var smsMessage = new Communication.SmsMessage(message, new[] { phoneNumber });
            await Sms.Default.ComposeAsync(smsMessage);
        }
        else
        {
            await DisplayAlert("Bd", "Funkcja wysyania SMS nie jest obsugiwana na tym urzdzeniu.", "OK");
        }
    }
    public void MakePhoneCallClicked(object sender, EventArgs e)
    {
        string phoneNumber = PhoneNumberEntry.Text;
        if (string.IsNullOrWhiteSpace(phoneNumber))
        {
            Console.WriteLine("Numer telefonu jest pusty lub nieprawidowy.");
            return;
        }

        try
        {
            PhoneDialer.Open(phoneNumber);
        }
        catch (FeatureNotSupportedException)
        {
            Console.WriteLine("Funkcja wybierania numeru nie jest wspierana na tym urzdzeniu.");
        }
        catch (Exception ex)
        {
            Console.WriteLine($"Wystpi bd: {ex.Message}");
        }
    }
    private async void OnGetLocationButtonClicked(object sender, EventArgs e)
    {
        await GetLocationAsync();
    }
    private async Task GetLocationAsync()
    {
        try
        {
            var location = await Geolocation.GetLastKnownLocationAsync();

            if (location != null)
            {
                await DisplayAlert("Lokalizacja", $"Szeroko: {location.Latitude}, Dugo: {location.Longitude}", "OK");
            }
            else
            {
                await DisplayAlert("Bd", "Nie udao si uzyska lokalizacji.", "OK");
            }
        }
        catch (FeatureNotSupportedException)
        {
            await DisplayAlert("Bd", "Funkcja lokalizacji nie jest wspierana na tym urzdzeniu.", "OK");
        }
        catch (Exception ex)
        {
            await DisplayAlert("Bd", $"Wystpi bd: {ex.Message}", "OK");
        }
    }
    private async void OnGetContactsClicked(object sender, EventArgs e)
    {
        try
        {
            var status = await Permissions.RequestAsync<Permissions.ContactsRead>();
            if (status != PermissionStatus.Granted)
            {
                await DisplayAlert("Brak dostpu", "Nie udzielono uprawnie do kontaktw.", "OK");
                return;
            }

            var contacts = await Communication.Contacts.Default.GetAllAsync();
            if (contacts == null || !contacts.Any())
            {
                await DisplayAlert("Brak kontaktw", "Nie znaleziono kontaktw na tym urzdzeniu.", "OK");
                return;
            }

            var contactList = contacts.Select(contact =>
            {
                string displayName = !string.IsNullOrWhiteSpace(contact.DisplayName) ? contact.DisplayName : "Brak nazwy";
                string phoneNumber = contact.Phones.FirstOrDefault()?.PhoneNumber ?? "Brak numeru";

                return new
                {
                    Name = displayName,
                    Phone = phoneNumber
                };
            }).ToList();

            ContactsList.ItemsSource = contactList;
        }
        catch (Exception ex)
        {
            await DisplayAlert("Bd", $"Wystpi bd podczas pobierania kontaktw: {ex.Message}", "OK");
        }
    }
  
}